@@ -31,6 +31,9 @@ rotateL (x:xs) = xs ++ [x]
 -- |A type for permutations, considered as functions or actions which can be performed on an underlying set.
 newtype Permutation a = P (M.Map a a) deriving (Eq,Ord)
 
+-- Can't make a Functor instance because we need an Ord instance
+fmapP f = fromPairs . map (\(x,y) -> (f x, f y)) . toPairs
+
 -- |Construct a permutation from a list of cycles.
 -- For example, @p [[1,2,3],[4,5]]@ returns the permutation that sends 1 to 2, 2 to 3, 3 to 1, 4 to 5, 5 to 4.
 p :: (Ord a) => [[a]] -> Permutation a
@@ -69,7 +72,8 @@ x .^ P g = case M.lookup x g of
 xs -^ g = L.sort [x .^ g | x <- xs]
 
 -- construct a permutation from cycles
-fromCycles cs = fromPairs $ concatMap fromCycle cs
+-- fromCycles cs = fromPairs $ concatMap fromCycle cs
+fromCycles cs = product $ map (fromPairs . fromCycle) cs
     where fromCycle xs = zip xs (rotateL xs)
 
 -- convert a permutation to cycles
@@ -94,7 +98,7 @@ orderElt g = foldl lcm 1 $ map length $ toCycles g
 
 -- |The Num instance is what enables us to write @g*h@ for the product of group elements and @1@ for the group identity.
 -- Unfortunately we can't of course give sensible definitions for the other functions declared in the Num typeclass.
-instance (Ord a, Show a) => Num (Permutation a) where
+instance Ord a => Num (Permutation a) where
     g * h = fromPairs' [(x, x .^ g .^ h) | x <- supp g `union` supp h]
     -- signum = sign -- doesn't work, complains about no (+) instance
     fromInteger 1 = P $ M.empty
@@ -104,13 +108,13 @@ instance (Ord a, Show a) => Num (Permutation a) where
     signum _ = error "(Permutation a).signum: not applicable"
 
 -- |The HasInverses instance is what enables us to write @g^-1@ for the inverse of a group element.
-instance (Ord a, Show a) => HasInverses (Permutation a) where
+instance Ord a => HasInverses (Permutation a) where
     inverse (P g) = P $ M.fromList $ map (\(x,y)->(y,x)) $ M.toList g
 
 
 -- |g ~^ h returns the conjugate of g by h, that is, h^-1*g*h.
 -- The tilde is meant to a mnemonic, because conjugacy is an equivalence relation.
-(~^) :: (Ord a, Show a) => Permutation a -> Permutation a -> Permutation a
+(~^) :: Ord a => Permutation a -> Permutation a -> Permutation a
 g ~^ h = h^-1 * g * h
 
 -- commutator
@@ -119,6 +123,7 @@ comm g h = g^-1 * h^-1 * g * h
 
 -- ORBITS
 
+{-
 closureS xs fs = closure' S.empty (S.fromList xs) where
     closure' interior boundary
         | S.null boundary = interior
@@ -126,6 +131,12 @@ closureS xs fs = closure' S.empty (S.fromList xs) where
             let interior' = S.union interior boundary
                 boundary' = S.fromList [f x | x <- S.toList boundary, f <- fs] S.\\ interior'
             in closure' interior' boundary'
+-}
+closureS xs fs = closure' S.empty xs where
+    closure' interior (x:xs)
+        | S.member x interior = closure' interior xs
+        | otherwise = closure' (S.insert x interior) ([f x | f <- fs] ++ xs)
+    closure' interior [] = interior
 
 closure xs fs = S.toList $ closureS xs fs
 
@@ -293,12 +304,20 @@ tgsFromSgs sgs = concatMap transversal bs where
 -- For example, sgs (_A 5) == [[[1,2,3]],[[2,4,5]],[[3,4,5]]]
 -- So we need all three to generate the first transversal, then the last two to generate the second transversal, etc
 
--- |Given a strong generating set, return the order of the group it generates
+-- |Given a strong generating set, return the order of the group it generates.
+-- Note that the SGS is assumed to be relative to the natural order of the points on which the group acts.
 orderSGS :: (Ord a) => [Permutation a] -> Integer
 orderSGS sgs = product $ map (L.genericLength . fundamentalOrbit) bs where
     bs = toListSet $ map minsupp sgs
     fundamentalOrbit b = b .^^ filter ( (b <=) . minsupp ) sgs
 
+-- !! Needs more testing
+-- |Given a base and strong generating set, return the order of the group it generates.
+orderBSGS :: (Ord a) => ([a],[Permutation a]) -> Integer
+orderBSGS (bs,sgs) = go 1 bs sgs where
+    go n [] _ = n
+    go n (b:bs) gs = go (n * L.genericLength (b .^^ gs)) bs (filter (\g -> b .^ g == b) gs)
+
 
 -- MORE INVESTIGATIONS
 
