@@ -1,10 +1,16 @@
--- Copyright (c) 2010, David Amos. All rights reserved.
+-- Copyright (c) 2010-2015, David Amos. All rights reserved.
 
 {-# LANGUAGE MultiParamTypeClasses, FlexibleInstances #-}
 
--- |A module defining the algebra of commutative polynomials over a field k
+-- |A module defining the algebra of commutative polynomials over a field k.
+--
+-- Most users should probably use Math.CommutativeAlgebra.Polynomial instead, which is basically the same thing
+-- but more fully-featured. This module will probably be deprecated at some point, but remains for now because
+-- it has a simpler implementation which may be more helpful for people wanting to understand the code.
 module Math.Algebras.Commutative where
 
+import Prelude hiding ( (*>) )
+
 import Math.Algebra.Field.Base hiding (powers)
 import Math.Algebras.VectorSpace
 import Math.Algebras.TensorProduct
@@ -36,6 +42,10 @@ instance Functor GlexMonomial where
     fmap f (Glex si xis) = Glex si [(f x, i) | (x,i) <- xis]
 -- Note that as we can't assume the Ord instance, we would need to call "nf" afterwards
 
+instance Applicative GlexMonomial where
+    pure = return
+    (<*>) = ap
+
 -- GlexMonomial is the free commutative monoid, and hence a monad
 instance Monad GlexMonomial where
     return x = Glex 1 [(x,1)]
