@@ -1,6 +1,6 @@
--- Copyright (c) 2010-2012, David Amos. All rights reserved.
+-- Copyright (c) 2010-2015, David Amos. All rights reserved.
 
-{-# LANGUAGE  MultiParamTypeClasses, FlexibleInstances, TypeSynonymInstances #-}
+{-# LANGUAGE  MultiParamTypeClasses, FlexibleInstances, FlexibleContexts, TypeSynonymInstances #-}
 -- ScopedTypeVariables
 
 -- |A module for doing arithmetic in the group algebra.
@@ -14,6 +14,8 @@
 -- For example, @p [[1,2,3]] + 2 * p [[1,2],[3,4]]@
 module Math.Algebras.GroupAlgebra (GroupAlgebra, p) where
 
+import Prelude hiding ( (*>) )
+
 import Math.Core.Field
 import Math.Core.Utils hiding (elts)
 
