@@ -32,7 +32,7 @@ instance Mon LaurentMonomial where
     mmult (LM si xis) (LM sj yjs) = LM (si+sj) $ addmerge xis yjs
 
 instance (Eq k, Num k) => Algebra k LaurentMonomial where
-    unit 0 = zero -- V []
+    unit 0 = zerov -- V []
     unit x = V [(munit,x)] 
     mult (V ts) = nf $ fmap (\(a,b) -> a `mmult` b) (V ts)
     -- mult (V ts) = nf $ V [(a `mmult` b, x) | (T a b, x) <- ts]
