@@ -1,10 +1,12 @@
--- Copyright (c) 2010, David Amos. All rights reserved.
+-- Copyright (c) 2010-2015, David Amos. All rights reserved.
 
 {-# LANGUAGE  MultiParamTypeClasses, FlexibleInstances #-}
 
 
 module Math.Algebras.Matrix where
 
+import Prelude hiding ( (*>) )
+
 import Math.Algebra.Field.Base
 import Math.Algebras.VectorSpace
 import Math.Algebras.TensorProduct
@@ -45,9 +47,9 @@ instance (Eq k, Num k) => Module k Mat2 EBasis where
 toMat2 [[a,b],[c,d]] = sum $ zipWith (\x e -> unit x * return e) [a,b,c,d] [E2 1 1, E2 1 2, E2 2 1, E2 2 2]
 -- fromMat2
 
-toEB2 [x,y] = foldl add zero $ zipWith (\x e -> x `smultL` return e) [x,y] [E 1, E 2]
+toEB2 [x,y] = foldl add zerov $ zipWith (\x e -> x `smultL` return e) [x,y] [E 1, E 2]
 
-toEB xs = foldl add zero $ zipWith (\x e -> x `smultL` return e) xs (map E [1..])
+toEB xs = foldl add zerov $ zipWith (\x e -> x `smultL` return e) xs (map E [1..])
 
 
 
@@ -58,7 +60,7 @@ data Mat2' = E2' Int Int deriving (Eq,Ord,Show)
 instance (Eq k, Num k) => Coalgebra k Mat2' where
     counit (V ts) = sum [xij * delta i j | (E2' i j, xij) <- ts]
     -- comult (V ts) = V $ concatMap (\(E2' i j,xij) -> [(T (E2' i k) (E2' k j), xij) | k <- [1..2]]) ts
-    comult = linear (\(E2' i j) -> foldl (<+>) zero [return (E2' i k, E2' k j) | k <- [1..2]])
+    comult = linear (\(E2' i j) -> foldl (<+>) zerov [return (E2' i k, E2' k j) | k <- [1..2]])
 -- In other words
 -- counit (a b) = (1 0)
 --        (c d)   (0 1)
@@ -74,7 +76,7 @@ data M3 = E3 Int Int deriving (Eq,Ord,Show)
 -- E i j represents the elementary matrix with a 1 at the (i,j) position, and 0s elsewhere
 
 instance (Eq k, Num k) => Algebra k M3 where
-    unit 0 = zero -- V []
+    unit 0 = zerov -- V []
     unit x = V [(E3 i i, x) | i <- [1..3] ]
     -- mult (V ts) = nf $ V $ map (\((E3 i j, E3 k l), x) -> (E3 i l, delta j k * x)) ts
     mult = linear mult' where
