@@ -1,10 +1,12 @@
--- Copyright (c) 2010, David Amos. All rights reserved.
+-- Copyright (c) 2010-2015, David Amos. All rights reserved.
 
 {-# LANGUAGE NoMonomorphismRestriction #-}
 
 -- |A module defining direct sum and tensor product of vector spaces
 module Math.Algebras.TensorProduct where
 
+import Prelude hiding ( (*>) )
+
 import Math.Algebras.VectorSpace
 
 infix 7 `te`, `tf`
@@ -38,12 +40,12 @@ coprodf f g = linear fg' where
 p1 :: (Eq k, Num k, Ord a) => Vect k (DSum a b) -> Vect k a
 p1 = linear p1' where
     p1' (Left a) = return a
-    p1' (Right b) = zero
+    p1' (Right b) = zerov
 
 -- |Projection onto right summand from direct sum
 p2 :: (Eq k, Num k, Ord b) => Vect k (DSum a b) -> Vect k b
 p2 = linear p2' where
-    p2' (Left a) = zero
+    p2' (Left a) = zerov
     p2' (Right b) = return b
 
 -- |The product of two linear functions (with the same source).
@@ -83,7 +85,7 @@ te (V us) (V vs) = V [((a,b), x*y) | (a,x) <- us, (b,y) <- vs]
 tf :: (Eq k, Num k, Ord a', Ord b') => (Vect k a -> Vect k a') -> (Vect k b -> Vect k b')
    -> Vect k (Tensor a b) -> Vect k (Tensor a' b')
 tf f g (V ts) = sum [x *> te (f $ return a) (g $ return b) | ((a,b), x) <- ts]
-    where sum = foldl add zero -- (V [])
+    where sum = foldl add zerov
 
 
 -- tensor isomorphisms
