@@ -1,5 +1,13 @@
 -- Copyright (c) 2008, David Amos. All rights reserved.
 
+-- |A module for constructing and working with combinatorial designs.
+--
+-- Given integers t \< k \< v and lambda > 0, a t-design or t-(v,k,lambda) design is an incidence structure of points X and blocks B,
+-- where X is a set of v points, B is a collection of k-subsets of X, with the property that any t points are contained
+-- in exactly lambda blocks. If lambda = 1 and t >= 2, then a t-design is also called a Steiner system S(t,k,v).
+--
+-- Many designs are highly symmetric structures, having large automorphism groups. In particular, the Mathieu groups,
+-- which were the first discovered sporadic finite simple groups, turn up as the automorphism groups of the Witt designs.
 module Math.Combinatorics.Design where
 
 import Data.Maybe (fromJust, isJust)
@@ -15,7 +23,7 @@ import Math.Algebra.Field.Extension
 import Math.Algebra.Group.PermutationGroup hiding (elts, order, isMember)
 import Math.Algebra.Group.SchreierSims as SS
 import Math.Combinatorics.Graph as G hiding (to1n, incidenceMatrix)
-import Math.Combinatorics.GraphAuts (refine', isSingleton, graphAuts, incidenceAuts) -- , removeGens)
+import Math.Combinatorics.GraphAuts (graphAuts, incidenceAuts) -- , removeGens)
 import Math.Combinatorics.FiniteGeometry
 
 -- Cameron & van Lint, Designs, Graphs, Codes and their Links
@@ -30,6 +38,7 @@ isSubset xs ys = all (`elem` ys) xs
 -- DESIGNS
 
 data Design a = D [a] [[a]] deriving (Eq,Ord,Show)
+-- Do we or should we insist on ordering of the xs or bs?
 
 design (xs,bs) | isValid d = d where d = D xs bs
 
@@ -112,14 +121,15 @@ pairDesign n = D vs es where
     vs = vertices graph
     es = edges graph
 
--- |The affine plane AG(2,Fq), a 2-(q^2,q,1) design
+-- |The affine plane AG(2,Fq), a 2-(q^2,q,1) design or Steiner system S(2,q,q^2).
 ag2 :: (FiniteField k, Ord k) => [k] -> Design [k]
 ag2 fq = design (points, lines) where
     points = ptsAG 2 fq
     lines = map line $ tail $ ptsPG 2 fq
     line [a,b,c] = [ [x,y] | [x,y] <- points, a*x+b*y+c==0 ]
 
--- |The projective plane PG(2,Fq), a square 2-(q^2+q+1,q+1,1) design
+-- |The projective plane PG(2,Fq), a square 2-(q^2+q+1,q+1,1) design or Steiner system S(2,q+1,q^2+q+1).
+-- For example, @pg2 f2@ is the Fano plane, a Steiner triple system S(2,3,7).
 pg2 :: (FiniteField k, Ord k) => [k] -> Design [k]
 pg2 fq = design (points, lines) where
     points = ptsPG 2 fq
