@@ -1,4 +1,4 @@
--- Copyright (c) 2011, David Amos. All rights reserved.
+-- Copyright (c) 2011-2015, David Amos. All rights reserved.
 
 {-# LANGUAGE NoMonomorphismRestriction, DeriveFunctor #-}
 
@@ -12,7 +12,7 @@ import Math.Core.Field hiding (f7)
 
 import Math.Common.ListSet as LS -- set operations on strictly ascending lists
 -- import Math.Algebra.Field.Base hiding (Q, F2, F3, F5, F7, F11, f2, f3, f5, f7, f11)
-import Math.Algebra.LinearAlgebra hiding (rank, (*>))
+import Math.Algebra.LinearAlgebra hiding (rank)
 
 import qualified Math.Combinatorics.Graph as G -- hiding (combinationsOf, restriction, component, isConnected)
 import Math.Combinatorics.FiniteGeometry
