@@ -281,10 +281,10 @@ quotientP fs g = map ( // g ) $ intersectI fs [g]
     where h // g = let ([u],_) = quotRemMP h [g] in u
 
 -- |@eliminate vs gs@ returns the elimination ideal obtained from the ideal generated by gs by eliminating the variables vs.
-eliminate :: (Fractional k, Ord k, MonomialConstructor m, Monomial (m v), Ord (m v)) =>
+eliminate :: (Eq k, Fractional k, Ord k, MonomialConstructor m, Monomial (m v), Ord (m v)) =>
     [Vect k (m v)] -> [Vect k (m v)] -> [Vect k (m v)]
 eliminate vs gs = let subs = subFst vs in eliminateFst [g `bind` subs | g <- gs]
-    where subFst :: (Num k, MonomialConstructor m, Eq (m v), Mon (m v)) =>
+    where subFst :: (Eq k, Num k, MonomialConstructor m, Eq (m v), Mon (m v)) =>
               [Vect k (m v)] -> v -> Vect k (Elim2 (m v) (m v))
           subFst vs = (\v -> let v' = var v in if v' `elem` vs then toElimFst v' else toElimSnd v')
 
@@ -386,4 +386,4 @@ hilbertPolyQA' gs = hilbertPolyQA vs gs where vs = toSet (concatMap vars gs)
 -- The dimension of a variety
 dim vs gs = 1 + deg (hilbertPolyQA vs gs)
 
-dim' gs = 1 + deg (hilbertPolyQA' gs)
\ No newline at end of file
+dim' gs = 1 + deg (hilbertPolyQA' gs)
