@@ -1,7 +1,9 @@
--- Copyright (c) 2008, David Amos. All rights reserved.
+-- Copyright (c) 2008-2015, David Amos. All rights reserved.
 
 module Math.Projects.ChevalleyGroup.Exceptional where
 
+import Prelude hiding ( (*>) )
+
 import Data.List as L
 
 -- import Math.Algebra.Field.Base
@@ -165,7 +167,7 @@ g2_3 = [alpha3', beta3', gamma3']
 
 -- Unit imaginary octonions form one orbit under the action of G2
 
--- [alpha', beta', gamma' generate G2(3) as a permutation group on 702 points (the number of unit imaginary octonions over F3)
+-- [alpha', beta', gamma'] generate G2(3) as a permutation group on 702 points (the number of unit imaginary octonions over F3)
 -- Interestingly, http://brauer.maths.qmul.ac.uk/Atlas/v3/exc/G23/ doesn't seem to have this permutation representation
 
 
